@@ -36,7 +36,7 @@ gvisIntensityMap <- function(data, locationvar="", numvar="", options=list(), ch
 
 gvisCheckIntensityMapData <- function(data, locationvar, numvar){
 
-  if(class(data) != "data.frame"){
+  if(! is.data.frame(data) ){
     stop("Error: data has to be a data.frame.")
   }
   if(locationvar=="")
